function [NumPort NumPts] = Write_SnP_Func( Freq, Snp, File_Save, ...
    Opt, Header)
% Freq    	: [column]
% Snp      	: {[column] ...}
% Snp(Freq)	: Opt.FreqPin='Freq', Header={'Hz' 'RI' 'S' '50'}
% Snp(Pin) 	: Opt.FreqPin='Pin',  Header={'DBM' 'RI' 'S' '50'}
% Opt.IOPortConv    ='Gen_2_ADSPNA2port' for 2port, [11 12 21 22]/[11 21 12 22]
% Opt.Precision     ='%16.15e '
% Opt.WriteHeader=1
if ~isfield( Opt,'IOPortConv' )
    disp('Missing Opt.IOPortConv')
    return
end
if ~isfield( Opt,'Precision' )
    Opt.Precision = '%16.15e ';
else
	Opt.Precision = [Opt.Precision ' '];
end

NumPts  = length( Freq )
NumPort = sqrt( length(Snp) )

fid = fopen(File_Save, 'w')
%% ########## Write Header
if (Opt.WriteHeader > 0)
%---------------------------------------------------------
switch Opt.FreqPin
    case{'Freq'}
        FormatSTR_1 = ['! freq()  '];
    case {'Pin'}
        FormatSTR_1 = ['! pin()  '];
end
%---------------------------------------------------------
if(NumPort==2)
    switch Opt.IOPortConv
        case{'Gen_2_ADSPNA2port'	'ADSPNA2port_2_ADSPNA2port'}
        FormatSTR_1 = [FormatSTR_1 're(11)  im(11)  re(21)  im(21)  re(12)  im(12)  re(22)  im(22)']
    end
else
	for nP1 = 1 : NumPort
	for nP2 = 1 : NumPort
        FormatSTR_1 = [FormatSTR_1  're(' num2str(nP1) num2str(nP2) ') '...
                                    'im(' num2str(nP1) num2str(nP2) ') '];
    end
	end
end
    fprintf(fid,'%s \n', FormatSTR_1);
%---------------------------------------------------------
HeaderSTR	= ['# ' Header{2} ' ' Header{3} ' ' Header{4} ' R ' Header{6}]
	fprintf(fid,'%s \n', HeaderSTR);
%---------------------------------------------------------
end

%% ########## Write Data: into MATRIX, fprintf MATRIX
if(NumPort==2)
    switch Opt.IOPortConv
        case{'Gen_2_Gen'            'ADSPNA2port_2_ADSPNA2port'}
            disp('Keep IOPortConvention for 2port')
        case{'Gen_2_ADSPNA2port'	'ADSPNA2port_2_Gen'}
            temp    = Snp{2};
            Snp{2}  = Snp{3};
            Snp{3}  = temp;
    end
end
SnpMAT = [ Freq ];
for nCEL = 1 : length( Snp )
	SnpMAT = [SnpMAT    Reshape_Func( real(Snp{nCEL}), [1;2] ) ...
                        Reshape_Func( imag(Snp{nCEL}), [1;2] ) ];
end
FormatSTR_2 = [repmat( Opt.Precision, 1, 1+2*NumPort^2) '\n']
fprintf(fid, FormatSTR_2, SnpMAT.');

fclose(fid); % frewind(fid)
%% Test
if(0)

%++++++++++++++ Write ADS
File_Save = fullfile(PATH.ADS_models, [DUT '_VSAys21' '.s2p'])
Write_SnP_Func(f_s21.', y_s21_Mat, ...
    File_Save, {'Freq' 'Gen' 1 '%10.9g'}, {'HZ' 'Y' 'RI' '1'});



Char= 'AMPM';
FileNam2 = 'SD513301_2000Mhz_-28dBm12dBmAtt0_100hz_401pts10ms_LSNA.s2p';
File_Load = fullfile(Path_PNA_Data, Char, FileNam2)
[Pin Snp_Pin] = Read_SnP_Func(File_Load, 2,'RI_dB','Gen');

Char= 'Model';
Ver = 'noheader';
Header	= {}; %'HZ' 'RI' '50'};
Opt_Pin     = {'DBM' 'RI' '50'};
%++++++++++++++ Write Freeda S21
File_Save = fullfile(Path_PNA_Data, Char, [DUT '_' Ver '.s2p'])
[NumPort NumPts] = Write_SnP_Func(Pin, Snp_Pin(3), ...
    File_Save, 'Gen', Header, Opt_Pin, 0)
%++++++++++++++ Write Freeda y11 y12 y21 y22
File_Save = fullfile(Path_PNA_Data, Char, [DUT '_' Ver '.y11'])
[NumPort NumPts] = Write_SnP_Func(Pin, Ynp_Pin(1), ...
    File_Save, 'Gen', Header, Opt_Pin, 0)
%++++++++++++++
File_Save = fullfile(Path_PNA_Data, Char, [DUT '_' Ver '.y12'])
[NumPort NumPts] = Write_SnP_Func(Pin, Ynp_Pin(2), ...
    File_Save, 'Gen', Header, Opt_Pin, 0)
%++++++++++++++
File_Save = fullfile(Path_PNA_Data, Char, [DUT '_' Ver '.y21'])
[NumPort NumPts] = Write_SnP_Func(Pin, Ynp_Pin(3), ...
    File_Save, 'Gen', Header, Opt_Pin, 0)
%++++++++++++++
File_Save = fullfile(Path_PNA_Data, Char, [DUT '_' Ver '.y22'])
[NumPort NumPts] = Write_SnP_Func(Pin, Ynp_Pin(4), ...
    File_Save, 'Gen', Header, Opt_Pin, 0)


Path_PNA_Data = 'M:\users\jhu\freeda_v13\components';
FileNam = 'test_y2p.s2p';
File_Save = fullfile(Path_PNA_Data, FileNam)
option = {'#' 'MHz' 'Y' 'RI' 'R' 50};
%
Write_SnP_Func(Freq, Snp, Path_PNA_Data, File_Save, option)

end